{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Entity Admin Graph" %}{% endblock %}

{% block page_header %}
{% include "horizon/common/_page_header.html" with title=_("Entity Graph") %}
{% endblock page_header %}

{% block main %}

<div ng-cloak ng-init='init({{ TOPOLOGY_VITRAGE_SETTINGS }})'>
    <ng-include src="'{{STATIC_URL}}dashboard/project/entities/entities.html'"></ng-include>
</div>

<!--<div ng-cloak ng-init='init({{ TOPOLOGY_VITRAGE_SETTINGS }})'>-->
    <!--<ng-include src="'{{STATIC_URL}}dashboard/project/layout/system-health.html'"></ng-include>-->
<!--</div>-->
{% endblock %}

